/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"context"
	"time"

	v1 "github.com/nokia/danm/crd/apis/danm/v1"
	scheme "github.com/nokia/danm/crd/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// DanmEpsGetter has a method to return a DanmEpInterface.
// A group's client should implement this interface.
type DanmEpsGetter interface {
	DanmEps(namespace string) DanmEpInterface
}

// DanmEpInterface has methods to work with DanmEp resources.
type DanmEpInterface interface {
	Create(ctx context.Context, danmEp *v1.DanmEp, opts metav1.CreateOptions) (*v1.DanmEp, error)
	Update(ctx context.Context, danmEp *v1.DanmEp, opts metav1.UpdateOptions) (*v1.DanmEp, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.DanmEp, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.DanmEpList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.DanmEp, err error)
	DanmEpExpansion
}

// danmEps implements DanmEpInterface
type danmEps struct {
	client rest.Interface
	ns     string
}

// newDanmEps returns a DanmEps
func newDanmEps(c *DanmV1Client, namespace string) *danmEps {
	return &danmEps{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the danmEp, and returns the corresponding danmEp object, and an error if there is any.
func (c *danmEps) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.DanmEp, err error) {
	result = &v1.DanmEp{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("danmeps").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of DanmEps that match those selectors.
func (c *danmEps) List(ctx context.Context, opts metav1.ListOptions) (result *v1.DanmEpList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.DanmEpList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("danmeps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested danmEps.
func (c *danmEps) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("danmeps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a danmEp and creates it.  Returns the server's representation of the danmEp, and an error, if there is any.
func (c *danmEps) Create(ctx context.Context, danmEp *v1.DanmEp, opts metav1.CreateOptions) (result *v1.DanmEp, err error) {
	result = &v1.DanmEp{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("danmeps").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(danmEp).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a danmEp and updates it. Returns the server's representation of the danmEp, and an error, if there is any.
func (c *danmEps) Update(ctx context.Context, danmEp *v1.DanmEp, opts metav1.UpdateOptions) (result *v1.DanmEp, err error) {
	result = &v1.DanmEp{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("danmeps").
		Name(danmEp.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(danmEp).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the danmEp and deletes it. Returns an error if one occurs.
func (c *danmEps) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("danmeps").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *danmEps) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("danmeps").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched danmEp.
func (c *danmEps) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.DanmEp, err error) {
	result = &v1.DanmEp{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("danmeps").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
