/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"context"
	"time"

	v1 "github.com/nokia/danm/crd/apis/danm/v1"
	scheme "github.com/nokia/danm/crd/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// DanmNetsGetter has a method to return a DanmNetInterface.
// A group's client should implement this interface.
type DanmNetsGetter interface {
	DanmNets(namespace string) DanmNetInterface
}

// DanmNetInterface has methods to work with DanmNet resources.
type DanmNetInterface interface {
	Create(ctx context.Context, danmNet *v1.DanmNet, opts metav1.CreateOptions) (*v1.DanmNet, error)
	Update(ctx context.Context, danmNet *v1.DanmNet, opts metav1.UpdateOptions) (*v1.DanmNet, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.DanmNet, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.DanmNetList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.DanmNet, err error)
	DanmNetExpansion
}

// danmNets implements DanmNetInterface
type danmNets struct {
	client rest.Interface
	ns     string
}

// newDanmNets returns a DanmNets
func newDanmNets(c *DanmV1Client, namespace string) *danmNets {
	return &danmNets{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the danmNet, and returns the corresponding danmNet object, and an error if there is any.
func (c *danmNets) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.DanmNet, err error) {
	result = &v1.DanmNet{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("danmnets").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of DanmNets that match those selectors.
func (c *danmNets) List(ctx context.Context, opts metav1.ListOptions) (result *v1.DanmNetList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.DanmNetList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("danmnets").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested danmNets.
func (c *danmNets) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("danmnets").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a danmNet and creates it.  Returns the server's representation of the danmNet, and an error, if there is any.
func (c *danmNets) Create(ctx context.Context, danmNet *v1.DanmNet, opts metav1.CreateOptions) (result *v1.DanmNet, err error) {
	result = &v1.DanmNet{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("danmnets").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(danmNet).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a danmNet and updates it. Returns the server's representation of the danmNet, and an error, if there is any.
func (c *danmNets) Update(ctx context.Context, danmNet *v1.DanmNet, opts metav1.UpdateOptions) (result *v1.DanmNet, err error) {
	result = &v1.DanmNet{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("danmnets").
		Name(danmNet.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(danmNet).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the danmNet and deletes it. Returns an error if one occurs.
func (c *danmNets) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("danmnets").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *danmNets) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("danmnets").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched danmNet.
func (c *danmNets) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.DanmNet, err error) {
	result = &v1.DanmNet{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("danmnets").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
